@@ -122,10 +122,10 @@ KateBuildView::KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
     , m_displayModeBeforeBuild(1)
     // NOTE this will not allow spaces in file names.
     // e.g. from gcc: "main.cpp:14: error: cannot convert ‘std::string’ to ‘int’ in return"
-    , m_filenameDetector(QStringLiteral("(([a-np-zA-Z]:[\\\\/])?[a-zA-Z0-9_\\.\\+\\-/\\\\]+\\.[a-zA-Z0-9]+):([0-9]+)(.*)"))
+    // e.g. from gcc: "main.cpp:14:8: error: cannot convert ‘std::string’ to ‘int’ in return"
     // e.g. from icpc: "main.cpp(14): error: no suitable conversion function from "std::string" to "int" exists"
-    , m_filenameDetectorIcpc(QStringLiteral("(([a-np-zA-Z]:[\\\\/])?[a-zA-Z0-9_\\.\\+\\-/\\\\]+\\.[a-zA-Z0-9]+)\\(([0-9]+)\\)(:.*)"))
-    , m_filenameDetectorGccWorked(false)
+    // e.g. from clang: ""main.cpp(14,8): fatal error: 'boost/scoped_array.hpp' file not found"
+    , m_filenameDetector(QStringLiteral("((?:[a-np-zA-Z]:[\\\\/])?[^\\s:(]+)[:\\(](\\d+)[,:]?(\\d+)?[\\):]* (.*)"))
     , m_newDirDetector(QStringLiteral("make\\[.+\\]: .+ '(.*)'"))
 {
     KXMLGUIClient::setComponentName(QStringLiteral("katebuild"), i18n("Kate Build Plugin"));
@@ -395,7 +395,33 @@ void KateBuildView::slotPrev()
     }
 }
 
+#ifdef Q_OS_WIN
 /******************************************************************/
+QString KateBuildView::caseFixed(const QString &path)
+{
+    QStringList paths = path.split(QLatin1Char('/'));
+    if (paths.isEmpty()) { return path; }
+
+    QString result = paths[0].toUpper() + QLatin1Char('/');
+    for (int i=1; i<paths.count(); ++i) {
+        QDir curDir(result);
+        const QStringList items = curDir.entryList();
+        int j;
+        for (j=0; j<items.size(); ++j) {
+            if (items[j].compare(paths[i], Qt::CaseInsensitive) == 0) {
+                result += items[j];
+                if (i < paths.count()-1) {
+                    result += QLatin1Char('/');
+                }
+                break;
+            }
+        }
+        if (j==items.size()) { return path; }
+    }
+    return result;
+}
+#endif
+
 void KateBuildView::slotErrorSelected(QTreeWidgetItem *item)
 {
     // any view active?
@@ -415,7 +441,7 @@ void KateBuildView::slotErrorSelected(QTreeWidgetItem *item)
     }
 
     // get stuff
-    const QString filename = item->data(0, Qt::UserRole).toString();
+    QString filename = item->data(0, Qt::UserRole).toString();
     if (filename.isEmpty()) {
         return;
     }
@@ -429,6 +455,16 @@ void KateBuildView::slotErrorSelected(QTreeWidgetItem *item)
         column = data.cursor->column();
     }
 
+#ifdef Q_OS_WIN
+    filename = caseFixed(filename);
+#endif
+
+    // Check if the file exists
+    if (!QFileInfo::exists(filename)) {
+        displayMessage(xi18nc("@info", "<title>Could not open file:</title><nl/>%1<br/>Try adding a search path to the working directory in the Target Settings", filename), KTextEditor::Message::Error);
+        return;
+    }
+
     // open file (if needed, otherwise, this will activate only the right view...)
     m_win->openUrl(QUrl::fromLocalFile(filename));
 
@@ -779,7 +815,7 @@ void KateBuildView::slotBuildPreviousTarget()
 /******************************************************************/
 void KateBuildView::slotBuildDefaultTarget()
 {
-    QModelIndex defaultTarget = m_targetsUi->targetsModel.defaultTarget(m_targetsUi->targetsView->currentIndex());
+    QModelIndex defaultTarget = m_targetsUi->targetsModel.defaultTarget(m_targetsUi->targetCombo->currentIndex());
     m_targetsUi->targetsView->setCurrentIndex(defaultTarget);
     buildCurrentTarget();
 }
@@ -819,7 +855,8 @@ bool KateBuildView::buildCurrentTarget()
 
     QString buildCmd = m_targetsUi->targetsModel.command(ind);
     QString cmdName = m_targetsUi->targetsModel.cmdName(ind);
-    QString workDir = m_targetsUi->targetsModel.workDir(ind);
+    m_searchPaths = m_targetsUi->targetsModel.workDir(ind).split(QLatin1Char(';'));
+    QString workDir = m_searchPaths.isEmpty() ? QString() : m_searchPaths.first();
     QString targetSet = m_targetsUi->targetsModel.targetName(ind);
 
     QString dir = workDir;
@@ -848,7 +885,6 @@ bool KateBuildView::buildCurrentTarget()
         buildCmd.replace(QStringLiteral("%f"), docFInfo.absoluteFilePath());
         buildCmd.replace(QStringLiteral("%d"), docFInfo.absolutePath());
     }
-    m_filenameDetectorGccWorked = false;
     m_currentlyBuildingTarget = QStringLiteral("%1: %2").arg(targetSet, cmdName);
     m_buildCancelled = false;
     QString msg = i18n("Building target <b>%1</b> ...", m_currentlyBuildingTarget);
@@ -874,6 +910,23 @@ void KateBuildView::displayBuildResult(const QString &msg, KTextEditor::Message:
     kv->document()->postMessage(m_infoMessage);
 }
 
+/******************************************************************/
+void KateBuildView::displayMessage(const QString &msg, KTextEditor::Message::MessageType level)
+{
+    KTextEditor::View *kv = m_win->activeView();
+    if (!kv)
+        return;
+
+    delete m_infoMessage;
+    m_infoMessage = new KTextEditor::Message(msg, level);
+    m_infoMessage->setWordWrap(true);
+    m_infoMessage->setPosition(KTextEditor::Message::BottomInView);
+    m_infoMessage->setAutoHide(8000);
+    m_infoMessage->setAutoHideMode(KTextEditor::Message::Immediate);
+    m_infoMessage->setView(kv);
+    kv->document()->postMessage(m_infoMessage);
+}
+
 /******************************************************************/
 void KateBuildView::slotProcExited(int exitCode, QProcess::ExitStatus)
 {
@@ -1002,20 +1055,6 @@ void KateBuildView::processLine(const QString &line)
     // look for a filename
     QRegularExpressionMatch match = m_filenameDetector.match(line);
 
-    if (match.hasMatch()) {
-        m_filenameDetectorGccWorked = true;
-    } else {
-        if (!m_filenameDetectorGccWorked) {
-            // let's see whether the icpc regexp works:
-            // so for icpc users error detection will be a bit slower,
-            // since always both regexps are checked.
-            // But this should be the minority, for gcc and clang users
-            // both regexes will only be checked until the first regex
-            // matched the first time.
-            match = m_filenameDetectorIcpc.match(line);
-        }
-    }
-
     if (!match.hasMatch()) {
         addError(QString(), QStringLiteral("0"), QString(), line);
         // kDebug() << "A filename was not found in the line ";
@@ -1023,15 +1062,30 @@ void KateBuildView::processLine(const QString &line)
     }
 
     QString filename = match.captured(1);
-    const QString line_n = match.captured(3);
+    const QString line_n = match.captured(2);
+    const QString col_n = match.captured(3);
     const QString msg = match.captured(4);
 
-    // qDebug() << "File Name:"<<filename<< " msg:"<< msg;
+#ifdef Q_OS_WIN
+    // convert '\' to '/' so the concatenation works
+    filename = QFileInfo(filename).filePath();
+#endif
+
+    //qDebug() << "File Name:"<<m_make_dir << filename << " msg:"<< msg;
     // add path to file
     if (QFile::exists(m_make_dir + QLatin1Char('/') + filename)) {
         filename = m_make_dir + QLatin1Char('/') + filename;
     }
 
+    // If we still do not have a file name try the extra search paths
+    int i = 1;
+    while (!QFile::exists(filename) && i < m_searchPaths.size()) {
+        if (QFile::exists(m_searchPaths[i] + QLatin1Char('/') + filename)) {
+            filename = m_searchPaths[i] + QLatin1Char('/') + filename;
+        }
+        i++;
+    }
+
     // get canonical path, if possible, to avoid duplicated opened files
     auto canonicalFilePath(QFileInfo(filename).canonicalFilePath());
     if (!canonicalFilePath.isEmpty()) {
@@ -1039,7 +1093,7 @@ void KateBuildView::processLine(const QString &line)
     }
 
     // Now we have the data we need show the error/warning
-    addError(filename, line_n, QStringLiteral("1"), msg);
+    addError(filename, line_n, col_n, msg);
 }
 
 /******************************************************************/
