@@ -26,6 +26,7 @@
 #define LSPCLIENTCONFIGPAGE_H
 
 #include <KTextEditor/ConfigPage>
+#include <KSyntaxHighlighting/Repository>
 
 class LSPClientPlugin;
 
@@ -50,10 +51,16 @@ public Q_SLOTS:
     void apply() override;
     void defaults() override;
     void reset() override;
+    void configTextChanged();
+    void configUrlChanged();
 
 private:
+    void readUserConfig(const QString &fileName);
+    void updateConfigTextErrorState();
+
     Ui::LspConfigWidget *ui;
     LSPClientPlugin *m_plugin;
+    KSyntaxHighlighting::Repository m_repository;
 };
 
 #endif
