@@ -176,7 +176,7 @@ class FileLineReader
 
 public:
     FileLineReader(const QUrl &url)
-        : file(url.path())
+        : file(url.toLocalFile())
     {
         file.open(QIODevice::ReadOnly);
     }
@@ -219,6 +219,7 @@ class LSPClientActionView : public QObject
     QScopedPointer<LSPClientViewTracker> m_viewTracker;
     QScopedPointer<LSPClientCompletion> m_completion;
     QScopedPointer<LSPClientHover> m_hover;
+    QScopedPointer<KTextEditor::TextHintProvider> m_forwardHover;
     QScopedPointer<QObject> m_symbolView;
 
     QPointer<QAction> m_findDef;
@@ -236,6 +237,7 @@ class LSPClientActionView : public QObject
     QPointer<QAction> m_diagnostics;
     QPointer<QAction> m_diagnosticsHighlight;
     QPointer<QAction> m_diagnosticsMark;
+    QPointer<QAction> m_diagnosticsHover;
     QPointer<QAction> m_diagnosticsSwitch;
     QPointer<QAction> m_messages;
     QPointer<KSelectAction> m_messagesAutoSwitch;
@@ -302,6 +304,23 @@ class LSPClientActionView : public QObject
         return m_client->actionCollection();
     }
 
+    // inner class that forwards directly to method for convenience
+    class ForwardingTextHintProvider : public KTextEditor::TextHintProvider
+    {
+        LSPClientActionView *m_parent;
+    public:
+        ForwardingTextHintProvider(LSPClientActionView *parent)
+            : m_parent(parent)
+        {
+            Q_ASSERT(m_parent);
+        }
+
+        virtual QString textHint(KTextEditor::View *view, const KTextEditor::Cursor &position) override
+        {
+            return m_parent->onTextHint(view, position);
+        }
+    };
+
 public:
     LSPClientActionView(LSPClientPlugin *plugin, KTextEditor::MainWindow *mainWin, KXMLGUIClient *client, QSharedPointer<LSPClientServerManager> serverManager)
         : QObject(mainWin)
@@ -311,6 +330,7 @@ public:
         , m_serverManager(std::move(serverManager))
         , m_completion(LSPClientCompletion::new_(m_serverManager))
         , m_hover(LSPClientHover::new_(m_serverManager))
+        , m_forwardHover(new ForwardingTextHintProvider(this))
         , m_symbolView(LSPClientSymbolView::new_(plugin, mainWin, m_serverManager))
     {
         connect(m_mainWindow, &KTextEditor::MainWindow::viewChanged, this, &self_type::updateState);
@@ -362,6 +382,9 @@ public:
         m_diagnosticsMark = actionCollection()->addAction(QStringLiteral("lspclient_diagnostics_mark"), this, &self_type::displayOptionChanged);
         m_diagnosticsMark->setText(i18n("Show diagnostics marks"));
         m_diagnosticsMark->setCheckable(true);
+        m_diagnosticsHover = actionCollection()->addAction(QStringLiteral("lspclient_diagnostics_hover"), this, &self_type::displayOptionChanged);
+        m_diagnosticsHover->setText(i18n("Show diagnostics on hover"));
+        m_diagnosticsHover->setCheckable(true);
         m_diagnosticsSwitch = actionCollection()->addAction(QStringLiteral("lspclient_diagnostic_switch"), this, &self_type::switchToDiagnostics);
         m_diagnosticsSwitch->setText(i18n("Switch to diagnostics tab"));
 
@@ -404,6 +427,7 @@ public:
         menu->addAction(m_diagnostics);
         menu->addAction(m_diagnosticsHighlight);
         menu->addAction(m_diagnosticsMark);
+        menu->addAction(m_diagnosticsHover);
         menu->addAction(m_diagnosticsSwitch);
         menu->addSeparator();
         menu->addAction(m_messages);
@@ -489,6 +513,7 @@ public:
     {
         m_diagnosticsHighlight->setEnabled(m_diagnostics->isChecked());
         m_diagnosticsMark->setEnabled(m_diagnostics->isChecked());
+        m_diagnosticsHover->setEnabled(m_diagnostics->isChecked());
         // messages tab should go first
         int messagesIndex = m_tabWidget->indexOf(m_messagesView);
         if (m_messages->isChecked() && m_messagesViewOwn) {
@@ -533,6 +558,8 @@ public:
             m_diagnosticsHighlight->setChecked(m_plugin->m_diagnosticsHighlight);
         if (m_diagnosticsMark)
             m_diagnosticsMark->setChecked(m_plugin->m_diagnosticsMark);
+        if (m_diagnosticsHover)
+            m_diagnosticsHover->setChecked(m_plugin->m_diagnosticsHover);
         if (m_messages)
             m_messages->setChecked(m_plugin->m_messages);
         if (m_messagesAutoSwitch)
@@ -615,10 +642,14 @@ public:
         KTextEditor::ConfigInterface *ciface = qobject_cast<KTextEditor::ConfigInterface *>(activeView);
 
         auto url = item->data(RangeData::FileUrlRole).toUrl();
-        if (url != doc->url())
+        // document url could end up empty while in intermediate reload state
+        // (and then it might match a parent item with no RangeData at all)
+        if (url != doc->url() || url.isEmpty())
             return;
 
         KTextEditor::Range range = item->data(RangeData::RangeRole).value<LSPRange>();
+        if (!range.isValid() || range.isEmpty())
+            return;
         auto line = range.start().line();
         RangeData::KindEnum kind = RangeData::KindEnum(item->data(RangeData::KindRole).toInt());
 
@@ -729,6 +760,8 @@ public:
         // ensure runtime match
         connect(doc, SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document *)), this, SLOT(clearAllMarks(KTextEditor::Document *)), Qt::UniqueConnection);
         connect(doc, SIGNAL(aboutToDeleteMovingInterfaceContent(KTextEditor::Document *)), this, SLOT(clearAllMarks(KTextEditor::Document *)), Qt::UniqueConnection);
+        // reload might save/restore marks before/after above signals, so let's clear before that
+        connect(doc, &KTextEditor::Document::aboutToReload, this, &self_type::clearAllMarks, Qt::UniqueConnection);
 
         if (handleClick) {
             connect(doc, SIGNAL(markClicked(KTextEditor::Document *, KTextEditor::Mark, bool &)), this, SLOT(onMarkClicked(KTextEditor::Document *, KTextEditor::Mark, bool &)), Qt::UniqueConnection);
@@ -1015,7 +1048,7 @@ public:
         for (const auto &loc : locations) {
             if (loc.uri != lastUrl) {
                 if (parent) {
-                    parent->setText(QStringLiteral("%1: %2").arg(lastUrl.path()).arg(parent->rowCount()));
+                    parent->setText(QStringLiteral("%1: %2").arg(lastUrl.toLocalFile()).arg(parent->rowCount()));
                 }
                 lastUrl = loc.uri;
                 parent = new QStandardItem();
@@ -1028,7 +1061,7 @@ public:
             fillItemRoles(item, loc.uri, loc.range, loc.kind, snapshot);
         }
         if (parent)
-            parent->setText(QStringLiteral("%1: %2").arg(lastUrl.path()).arg(parent->rowCount()));
+            parent->setText(QStringLiteral("%1: %2").arg(lastUrl.toLocalFile()).arg(parent->rowCount()));
 
         // plain heuristic; mark for auto-expand all when safe and/or useful to do so
         if (treeModel->rowCount() <= 2 || locations.size() <= 20) {
@@ -1372,13 +1405,34 @@ public:
 
     static QStandardItem *getItem(const QStandardItemModel &model, const QUrl &url)
     {
-        auto l = model.findItems(url.path());
+        auto l = model.findItems(url.toLocalFile());
         if (l.length()) {
             return l.at(0);
         }
         return nullptr;
     }
 
+    static QStandardItem *getItem(const QStandardItem *topItem, KTextEditor::Cursor pos, bool onlyLine)
+    {
+        QStandardItem *targetItem = nullptr;
+        if (topItem) {
+            int count = topItem->rowCount();
+            // let's not run wild on a linear search in a flood of diagnostics
+            // user is already in enough trouble as it is ;-)
+            if (count > 50)
+                count = 0;
+            for (int i = 0; i < count; ++i) {
+                auto item = topItem->child(i);
+                auto range = item->data(RangeData::RangeRole).value<LSPRange>();
+                if ((onlyLine && pos.line() == range.start().line()) || (range.contains(pos))) {
+                    targetItem = item;
+                    break;
+                }
+            }
+        }
+        return targetItem;
+    }
+
     // select/scroll to diagnostics item for document and (optionally) line
     bool syncDiagnostics(KTextEditor::Document *document, int line, bool allowTop, bool doShow)
     {
@@ -1386,23 +1440,10 @@ public:
             return false;
 
         auto hint = QAbstractItemView::PositionAtTop;
-        QStandardItem *targetItem = nullptr;
         QStandardItem *topItem = getItem(*m_diagnosticsModel, document->url());
-        if (topItem) {
-            int count = topItem->rowCount();
-            // let's not run wild on a linear search in a flood of diagnostics
-            // user is already in enough trouble as it is ;-)
-            if (count > 50)
-                count = 0;
-            for (int i = 0; i < count; ++i) {
-                auto item = topItem->child(i);
-                int itemline = item->data(RangeData::RangeRole).value<LSPRange>().start().line();
-                if (line == itemline && m_diagnosticsTree) {
-                    targetItem = item;
-                    hint = QAbstractItemView::PositionAtCenter;
-                    break;
-                }
-            }
+        QStandardItem *targetItem = getItem(topItem, {line, 0}, true);
+        if (targetItem) {
+            hint = QAbstractItemView::PositionAtCenter;
         }
         if (!targetItem && allowTop) {
             targetItem = topItem;
@@ -1463,7 +1504,7 @@ public:
             }
             topItem = new QStandardItem();
             model->appendRow(topItem);
-            topItem->setText(diagnostics.uri.path());
+            topItem->setText(diagnostics.uri.toLocalFile());
         } else {
             topItem->setRowCount(0);
         }
@@ -1485,7 +1526,7 @@ public:
                 }
                 auto relatedItemMessage = new QStandardItem();
                 fillItemRoles(relatedItemMessage, related.location.uri, related.location.range, RangeData::KindEnum::Related);
-                auto basename = QFileInfo(related.location.uri.path()).fileName();
+                auto basename = QFileInfo(related.location.uri.toLocalFile()).fileName();
                 auto location = QStringLiteral("%1:%2").arg(basename).arg(related.location.range.start().line());
                 relatedItemMessage->setText(QStringLiteral("[%1] %2").arg(location).arg(related.message));
                 relatedItemMessage->setData(diagnosticsIcon(LSPDiagnosticSeverity::Information), Qt::DecorationRole);
@@ -1501,6 +1542,48 @@ public:
         m_diagnosticsTree->scrollTo(topItem->index(), QAbstractItemView::PositionAtTop);
 
         updateState();
+        // also sync updated diagnositic to current position
+        auto currentView = m_mainWindow->activeView();
+        if (currentView && currentView->document())
+            syncDiagnostics(currentView->document(), currentView->cursorPosition().line(), false, false);
+    }
+
+    QString onTextHint(KTextEditor::View *view, const KTextEditor::Cursor &position)
+    {
+        QString result;
+        auto document = view->document();
+
+        if (!m_diagnosticsTree || !m_diagnosticsModel || !document)
+            return result;
+
+        bool autoHover = m_autoHover && m_autoHover->isChecked();
+        bool diagHover = m_diagnostics && m_diagnostics->isChecked() && m_diagnosticsHover && m_diagnosticsHover->isChecked();
+
+        QStandardItem *topItem = diagHover ? getItem(*m_diagnosticsModel, document->url()) : nullptr;
+        QStandardItem *targetItem = getItem(topItem, position, false);
+        if (targetItem) {
+            result = targetItem->text();
+            // also include related info
+            int count = targetItem->rowCount();
+            for (int i = 0; i < count; ++i) {
+                auto item = targetItem->child(i);
+                result += QStringLiteral("\n<br>");
+                result += item->text();
+            }
+            // but let's not get carried away too far
+            const int maxsize = m_plugin->m_diagnosticsSize;
+            if (result.size() > maxsize) {
+                result.resize(maxsize);
+                result.append(QStringLiteral("..."));
+            }
+        } else if (autoHover) {
+            // only trigger generic hover if no diagnostic to show;
+            // avoids interference by generic hover info
+            // (which is likely not so useful in this case/position anyway)
+            result = m_hover->textHint(view, position);
+        }
+
+        return result;
     }
 
     KTextEditor::View *viewForUrl(const QUrl &url) const
@@ -1756,7 +1839,7 @@ public:
         QSet<QString> fpaths;
         for (const auto &view : m_mainWindow->views()) {
             if (auto doc = view->document()) {
-                fpaths.insert(doc->url().path());
+                fpaths.insert(doc->url().toLocalFile());
             }
         }
         // check and clear defunct entries
@@ -1857,8 +1940,10 @@ public:
         updateCompletion(activeView, server.data());
 
         // update hover with relevant server
-        m_hover->setServer(server);
-        updateHover(activeView, (m_autoHover && m_autoHover->isChecked()) ? server.data() : nullptr);
+        m_hover->setServer(server && server->capabilities().hoverProvider ? server : nullptr);
+        // need hover either for generic documentHover or for diagnostics
+        // so register anyway if server available and will sort out what to do/show later
+        updateHover(activeView, server.data());
 
         // update marks if applicable
         if (m_markModel && doc)
@@ -1914,15 +1999,15 @@ public:
         KTextEditor::TextHintInterface *cci = qobject_cast<KTextEditor::TextHintInterface *>(view);
         Q_ASSERT(cci);
 
-        if (!registered && server && server->capabilities().hoverProvider) {
-            qCInfo(LSPCLIENT) << "registering cci";
-            cci->registerTextHintProvider(m_hover.data());
+        if (!registered && server) {
+            qCInfo(LSPCLIENT) << "registering thi";
+            cci->registerTextHintProvider(m_forwardHover.data());
             m_hoverViews.insert(view);
         }
 
         if (registered && !server) {
-            qCInfo(LSPCLIENT) << "unregistering cci";
-            cci->unregisterTextHintProvider(m_hover.data());
+            qCInfo(LSPCLIENT) << "unregistering thi";
+            cci->unregisterTextHintProvider(m_forwardHover.data());
             m_hoverViews.remove(view);
         }
     }
@@ -1943,11 +2028,13 @@ public:
         : QObject(mainWin)
         , m_mainWindow(mainWin)
         , m_serverManager(LSPClientServerManager::new_(plugin, mainWin))
-        , m_actionView(new LSPClientActionView(plugin, mainWin, this, m_serverManager))
     {
         KXMLGUIClient::setComponentName(QStringLiteral("lspclient"), i18n("LSP Client"));
         setXMLFile(QStringLiteral("ui.rc"));
 
+        // we need to do this AFTER the setComponentName above
+        m_actionView.reset(new LSPClientActionView(plugin, mainWin, this, m_serverManager));
+
         m_mainWindow->guiFactory()->addClient(this);
     }
 
