@@ -332,6 +332,18 @@ static QUrl normalizeUrl(const QUrl &url)
     return url.adjusted(QUrl::NormalizePathSegments);
 }
 
+static LSPResponseError parseResponseError(const QJsonValue &v)
+{
+    LSPResponseError ret;
+    if (v.isObject()) {
+        const auto &vm = v.toObject();
+        ret.code = LSPErrorCode(vm.value(MEMBER_CODE).toInt());
+        ret.message = vm.value(MEMBER_MESSAGE).toString();
+        ret.data = vm.value(QStringLiteral("data"));
+    }
+    return ret;
+}
+
 static LSPMarkupContent parseMarkupContent(const QJsonValue &v)
 {
     LSPMarkupContent ret;
@@ -756,7 +768,8 @@ class LSPClientServer::LSPClientServerPrivate
     // receive buffer
     QByteArray m_receive;
     // registered reply handlers
-    QHash<int, GenericReplyHandler> m_handlers;
+    // (result handler, error result handler)
+    QHash<int, std::pair<GenericReplyHandler, GenericReplyHandler>> m_handlers;
     // pending request responses
     static constexpr int MAX_REQUESTS = 5;
     QVector<int> m_requests {MAX_REQUESTS + 1};
@@ -822,7 +835,7 @@ private:
         }
     }
 
-    RequestHandle write(const QJsonObject &msg, const GenericReplyHandler &h = nullptr, const int *id = nullptr)
+    RequestHandle write(const QJsonObject &msg, const GenericReplyHandler &h = nullptr, const GenericReplyHandler &eh = nullptr, const int *id = nullptr)
     {
         RequestHandle ret;
         ret.m_server = q;
@@ -836,7 +849,7 @@ private:
         if (h) {
             ob.insert(MEMBER_ID, ++m_id);
             ret.m_id = m_id;
-            m_handlers[m_id] = h;
+            m_handlers[m_id] = {h, eh};
         } else if (id) {
             ob.insert(MEMBER_ID, *id);
         }
@@ -856,10 +869,10 @@ private:
         return ret;
     }
 
-    RequestHandle send(const QJsonObject &msg, const GenericReplyHandler &h = nullptr)
+    RequestHandle send(const QJsonObject &msg, const GenericReplyHandler &h = nullptr, const GenericReplyHandler &eh = nullptr)
     {
         if (m_state == State::Running)
-            return write(msg, h);
+            return write(msg, h, eh);
         else
             qCWarning(LSPCLIENT) << "send for non-running server";
         return RequestHandle();
@@ -922,7 +935,13 @@ private:
             // check if it is the expected result
             int msgid = -1;
             if (result.contains(MEMBER_ID)) {
-                msgid = result[MEMBER_ID].toInt();
+                // allow id to be returned as a string value, happens e.g. for Perl LSP server
+                const auto idValue = result[MEMBER_ID];
+                if (idValue.isString()) {
+                    msgid = idValue.toString().toInt();
+                } else {
+                    msgid = idValue.toInt();
+                }
             } else {
                 processNotification(result);
                 continue;
@@ -943,10 +962,18 @@ private:
                 m_handlers.erase(it);
 
                 // run handler, might e.g. trigger some new LSP actions for this server
-                handler(result.value(MEMBER_RESULT));
+                // process and provide error if caller interested,
+                // otherwise reply will resolve to 'empty' response
+                auto &h = handler.first;
+                auto &eh = handler.second;
+                if (result.contains(MEMBER_ERROR) && eh) {
+                    eh(result.value(MEMBER_ERROR));
+                } else {
+                    h(result.value(MEMBER_RESULT));
+                }
             } else {
                 // could have been canceled
-                qCDebug(LSPCLIENT) << "unexpected reply id";
+                qCDebug(LSPCLIENT) << "unexpected reply id" << msgid;
             }
         }
     }
@@ -1016,7 +1043,7 @@ private:
         // NOTE a typical server does not use root all that much,
         // other than for some corner case (in) requests
         QJsonObject params {{QStringLiteral("processId"), QCoreApplication::applicationPid()},
-                            {QStringLiteral("rootPath"), m_root.path()},
+                            {QStringLiteral("rootPath"), m_root.toLocalFile()},
                             {QStringLiteral("rootUri"), m_root.toString()},
                             {QStringLiteral("capabilities"), capabilities},
                             {QStringLiteral("initializationOptions"), m_init}};
@@ -1042,7 +1069,7 @@ public:
         qCInfo(LSPCLIENT) << "starting" << m_server << "with root" << m_root;
 
         // start LSP server in project root
-        m_sproc.setWorkingDirectory(m_root.path());
+        m_sproc.setWorkingDirectory(m_root.toLocalFile());
 
         // at least we see some errors somewhere then
         m_sproc.setProcessChannelMode(QProcess::ForwardedErrorChannel);
@@ -1070,10 +1097,10 @@ public:
         }
     }
 
-    RequestHandle documentSymbols(const QUrl &document, const GenericReplyHandler &h)
+    RequestHandle documentSymbols(const QUrl &document, const GenericReplyHandler &h, const GenericReplyHandler &eh)
     {
         auto params = textDocumentParams(document);
-        return send(init_request(QStringLiteral("textDocument/documentSymbol"), params), h);
+        return send(init_request(QStringLiteral("textDocument/documentSymbol"), params), h, eh);
     }
 
     RequestHandle documentDefinition(const QUrl &document, const LSPPosition &pos, const GenericReplyHandler &h)
@@ -1203,15 +1230,6 @@ public:
         }
     }
 
-    template<typename ReplyType> static GenericReplyHandler make_handler(const ReplyHandler<ReplyType> &h, const QObject *context, typename utils::identity<std::function<ReplyType(const GenericReplyType &)>>::type c)
-    {
-        QPointer<const QObject> ctx(context);
-        return [ctx, h, c](const GenericReplyType &m) {
-            if (ctx)
-                h(c(m));
-        };
-    }
-
     GenericReplyHandler prepareResponse(int msgid)
     {
         // allow limited number of outstanding requests
@@ -1227,7 +1245,7 @@ public:
             auto index = m_requests.indexOf(msgid);
             if (index >= 0) {
                 m_requests.remove(index);
-                write(init_response(response), nullptr, &msgid);
+                write(init_response(response), nullptr, nullptr, &msgid);
             } else {
                 qCWarning(LSPCLIENT) << "discarding response" << msgid;
             }
@@ -1251,7 +1269,7 @@ public:
             auto h = responseHandler<LSPApplyWorkspaceEditResponse>(prepareResponse(msgid), applyWorkspaceEditResponse);
             emit q->applyEdit(parseApplyWorkspaceEditParams(params.toObject()), h, handled);
         } else {
-            write(init_error(LSPErrorCode::MethodNotFound, method), nullptr, &msgid);
+            write(init_error(LSPErrorCode::MethodNotFound, method), nullptr, nullptr, &msgid);
             qCWarning(LSPCLIENT) << "discarding request" << method;
         }
     }
@@ -1263,6 +1281,10 @@ public:
 // but in case the latter would be changed in surprising ways ...
 template<typename ReplyType> static GenericReplyHandler make_handler(const ReplyHandler<ReplyType> &h, const QObject *context, typename utils::identity<std::function<ReplyType(const GenericReplyType &)>>::type c)
 {
+    // empty provided handler leads to empty handler
+    if (!h || !c)
+        return nullptr;
+
     QPointer<const QObject> ctx(context);
     return [ctx, h, c](const GenericReplyType &m) {
         if (ctx)
@@ -1320,9 +1342,9 @@ int LSPClientServer::cancel(int reqid)
     return d->cancel(reqid);
 }
 
-LSPClientServer::RequestHandle LSPClientServer::documentSymbols(const QUrl &document, const QObject *context, const DocumentSymbolsReplyHandler &h)
+LSPClientServer::RequestHandle LSPClientServer::documentSymbols(const QUrl &document, const QObject *context, const DocumentSymbolsReplyHandler &h, const ErrorReplyHandler &eh)
 {
-    return d->documentSymbols(document, make_handler(h, context, parseDocumentSymbols));
+    return d->documentSymbols(document, make_handler(h, context, parseDocumentSymbols), make_handler(eh, context, parseResponseError));
 }
 
 LSPClientServer::RequestHandle LSPClientServer::documentDefinition(const QUrl &document, const LSPPosition &pos, const QObject *context, const DocumentDefinitionReplyHandler &h)
