@@ -32,8 +32,7 @@
 #include <kmessagewidget.h>
 
 KateProjectInfoViewCodeAnalysis::KateProjectInfoViewCodeAnalysis(KateProjectPluginView *pluginView, KateProject *project)
-    : QWidget()
-    , m_pluginView(pluginView)
+    : m_pluginView(pluginView)
     , m_project(project)
     , m_messageWidget(nullptr)
     , m_startStopAnalysis(new QPushButton(i18n("Start Analysis...")))
@@ -67,11 +66,7 @@ KateProjectInfoViewCodeAnalysis::KateProjectInfoViewCodeAnalysis(KateProjectPlug
      * Connect selection change callback
      * and attach model to code analysis selector
      */
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_toolSelector, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &KateProjectInfoViewCodeAnalysis::slotToolSelectionChanged);
-#else
-    connect(m_toolSelector, static_cast<void (QComboBox::*)(int, const QString &)>(&QComboBox::currentIndexChanged) , this, &KateProjectInfoViewCodeAnalysis::slotToolSelectionChanged);
-#endif
     m_toolSelector->setModel(KateProjectCodeAnalysisSelector::model(this));
 
     /**
