@@ -90,7 +90,11 @@ QString KateProjectCodeAnalysisToolFlake8::notInstalledMessage() const
 
 QStringList KateProjectCodeAnalysisToolFlake8::parseLine(const QString &line) const
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     return line.split(QRegularExpression(QStringLiteral("////")), QString::SkipEmptyParts);
+#else
+    return line.split(QRegularExpression(QStringLiteral("////")), Qt::SkipEmptyParts);
+#endif
 }
 
 QString KateProjectCodeAnalysisToolFlake8::stdinMessages()
