@@ -45,8 +45,12 @@ void FolderFilesList::run()
     QFileInfo folderInfo(m_folder);
     checkNextItem(folderInfo);
 
-    if (m_cancelSearch)
+    if (m_cancelSearch) {
         m_files.clear();
+    }
+    else {
+        Q_EMIT fileListReady();
+    }
 }
 
 void FolderFilesList::generateList(const QString &folder, bool recursive, bool hidden, bool symlinks, bool binary, const QString &types, const QString &excludes)
@@ -62,7 +66,11 @@ void FolderFilesList::generateList(const QString &folder, bool recursive, bool h
     m_binary = binary;
 
     m_types.clear();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const auto typesList = types.split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+    const auto typesList = types.split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
     for (const QString &type : typesList) {
         m_types << type.trimmed();
     }
@@ -82,6 +90,12 @@ void FolderFilesList::generateList(const QString &folder, bool recursive, bool h
     start();
 }
 
+void FolderFilesList::terminateSearch()
+{
+    m_cancelSearch = true;
+    wait();
+}
+
 QStringList FolderFilesList::fileList()
 {
     return m_files;
