@@ -1,6 +1,6 @@
 /*   Kate search plugin
  *
- * Copyright (C) 2011-2013 by Kåre Särs <kare.sars@iki.fi>
+ * Copyright (C) 2011-2020 by Kåre Särs <kare.sars@iki.fi>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  */
 
 #include "plugin_search.h"
-
+#include "KateSearchCommand.h"
 #include "htmldelegate.h"
 
 #include <ktexteditor/application.h>
@@ -55,6 +55,7 @@
 #include <QMetaObject>
 #include <QScrollBar>
 #include <QTextDocument>
+#include <QPoint>
 
 static QUrl localFileDirUp(const QUrl &url)
 {
@@ -314,14 +315,6 @@ void KatePluginSearchView::nextFocus(QWidget *currentWidget, bool *found, bool n
 KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEditor::MainWindow *mainWin, KTextEditor::Application *application)
     : QObject(mainWin)
     , m_kateApp(application)
-    , m_curResults(nullptr)
-    , m_searchJustOpened(false)
-    , m_projectSearchPlaceIndex(0)
-    , m_searchDiskFilesDone(true)
-    , m_searchOpenFilesDone(true)
-    , m_isSearchAsYouType(false)
-    , m_isLeftRight(false)
-    , m_projectPluginView(nullptr)
     , m_mainWindow(mainWin)
 {
     KXMLGUIClient::setComponentName(QStringLiteral("katesearch"), i18n("Kate Search & Replace"));
@@ -426,10 +419,7 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
         }
     });
 
-    connect(m_ui.stopButton, &QPushButton::clicked, &m_searchOpenFiles, &SearchOpenFiles::cancelSearch);
-    connect(m_ui.stopButton, &QPushButton::clicked, &m_searchDiskFiles, &SearchDiskFiles::cancelSearch);
-    connect(m_ui.stopButton, &QPushButton::clicked, &m_folderFilesList, &FolderFilesList::cancelSearch);
-    connect(m_ui.stopButton, &QPushButton::clicked, &m_replacer, &ReplaceMatches::cancelReplace);
+    connect(m_ui.stopButton, &QPushButton::clicked, this, &KatePluginSearchView::stopClicked);
 
     connect(m_ui.nextButton, &QToolButton::clicked, this, &KatePluginSearchView::goToNextMatch);
 
@@ -443,7 +433,7 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
     connect(&m_searchOpenFiles, &SearchOpenFiles::searchDone, this, &KatePluginSearchView::searchDone);
     connect(&m_searchOpenFiles, static_cast<void (SearchOpenFiles::*)(const QString &)>(&SearchOpenFiles::searching), this, &KatePluginSearchView::searching);
 
-    connect(&m_folderFilesList, &FolderFilesList::finished, this, &KatePluginSearchView::folderFileListChanged);
+    connect(&m_folderFilesList, &FolderFilesList::fileListReady, this, &KatePluginSearchView::folderFileListChanged);
     connect(&m_folderFilesList, &FolderFilesList::searching, this, &KatePluginSearchView::searching);
 
     connect(&m_searchDiskFiles, &SearchDiskFiles::matchFound, this, &KatePluginSearchView::matchFound);
@@ -659,6 +649,12 @@ void KatePluginSearchView::toggleOptions(bool show)
 
 void KatePluginSearchView::setSearchPlace(int place)
 {
+    if (place >= m_ui.searchPlaceCombo->count()) {
+        // This probably means the project plugin is not active or no project loaded
+        // fallback to search in folder
+        qDebug() << place << "is not a valid search place index";
+        place = Folder;
+    }
     m_ui.searchPlaceCombo->setCurrentIndex(place);
 }
 
@@ -932,7 +928,7 @@ static const int contextLen = 70;
 
 void KatePluginSearchView::matchFound(const QString &url, const QString &fName, const QString &lineContent, int matchLen, int startLine, int startColumn, int endLine, int endColumn)
 {
-    if (!m_curResults) {
+    if (!m_curResults || (sender() == &m_searchDiskFiles && m_blockDiskMatchFound)) {
         return;
     }
     int preLen = contextLen;
@@ -1015,8 +1011,31 @@ void KatePluginSearchView::clearDocMarks(KTextEditor::Document *doc)
     }
 }
 
+void KatePluginSearchView::stopClicked()
+{
+    m_folderFilesList.cancelSearch();
+    m_searchOpenFiles.cancelSearch();
+    m_searchDiskFiles.cancelSearch();
+    m_replacer.cancelReplace();
+    m_searchDiskFilesDone = true;
+    m_searchOpenFilesDone = true;
+    searchDone(); // Just in case the folder list was being populated...
+}
+
 void KatePluginSearchView::startSearch()
 {
+    // Forcefully stop any ongoing search or replace
+    m_blockDiskMatchFound = true; // Do not allow leftover machFound:s from a previous search to be added
+    m_folderFilesList.terminateSearch();
+    m_searchOpenFiles.terminateSearch();
+    m_searchDiskFiles.terminateSearch();
+    // Re-enable the handling of fisk-file-matches after one event loop
+    // For some reason blocking of signals or disconnect/connect does not prevent the slot from being called,
+    // so we use m_blockDiskMatchFound to skip any old matchFound signals during the first event loop.
+    // New matches from disk-files should not come before the first event loop has executed.
+    QTimer::singleShot(0, this, [this]() { m_blockDiskMatchFound = false; });
+    m_replacer.terminateReplace();
+
     m_changeTimer.stop();                       // make sure not to start a "while you type" search now
     m_mainWindow->showToolView(m_toolView);     // in case we are invoked from the command interface
     m_projectSearchPlaceIndex = 0;              // now that we started, don't switch back automatically
@@ -1176,6 +1195,7 @@ void KatePluginSearchView::startSearch()
         }
         m_searchDiskFiles.startSearch(files, reg);
     } else {
+        qDebug() << "Case not handled:" << m_ui.searchPlaceCombo->currentIndex();
         Q_ASSERT_X(false, "KatePluginSearchView::startSearch", "case not handled");
     }
 }
@@ -2025,8 +2045,10 @@ void KatePluginSearchView::addTab()
     Results *res = new Results();
 
     res->tree->setRootIsDecorated(false);
+    res->tree->setContextMenuPolicy(Qt::CustomContextMenu);
 
     connect(res->tree, &QTreeWidget::itemDoubleClicked, this, &KatePluginSearchView::itemSelected, Qt::UniqueConnection);
+    connect(res->tree, &QTreeWidget::customContextMenuRequested, this, &KatePluginSearchView::customResMenuRequested, Qt::UniqueConnection);
 
     res->searchPlaceIndex = m_ui.searchPlaceCombo->currentIndex();
     res->useRegExp = m_ui.useRegExp->isChecked();
@@ -2046,6 +2068,7 @@ void KatePluginSearchView::tabCloseRequested(int index)
     if (m_curResults == tmp) {
         m_searchOpenFiles.cancelSearch();
         m_searchDiskFiles.cancelSearch();
+        m_folderFilesList.cancelSearch();
     }
     if (m_ui.resultTabWidget->count() > 1) {
         delete tmp; // remove the tab
@@ -2134,16 +2157,130 @@ void KatePluginSearchView::onResize(const QSize &size)
     }
 }
 
+void KatePluginSearchView::customResMenuRequested(const QPoint &pos)
+{
+    QTreeWidget *tree = qobject_cast<QTreeWidget *>(sender());
+    if (tree == nullptr) {
+        return;
+    }
+    QMenu *menu = new QMenu(tree);
+
+    QAction *copyAll = new QAction(i18n("Copy all"), tree);
+    copyAll->setShortcut(QKeySequence::Copy);
+    copyAll->setShortcutVisibleInContextMenu(true);
+    menu->addAction(copyAll);
+
+    QAction *copyExpanded = new QAction(i18n("Copy expanded"), tree);
+    menu->addAction(copyExpanded);
+
+    menu->popup(tree->viewport()->mapToGlobal(pos));
+
+    connect(copyAll, &QAction::triggered, this, [this](bool) { copySearchToClipboard(All); });
+    connect(copyExpanded, &QAction::triggered, this, [this](bool) { copySearchToClipboard(AllExpanded); });
+}
+
+static QString copySearchSummary(const QTreeWidgetItem *summaryItem)
+{
+    if (summaryItem) {
+        int matches = 0;
+        for (int i=0; i<summaryItem->childCount(); ++i) {
+            matches += summaryItem->child(i)->childCount();
+        }
+        return i18np("A total of %1 match found\n", "A total of %1 matches found\n", matches);
+    }
+    return QString();
+}
+
+static QString copySearchMatchFile(QTreeWidgetItem *fileItem)
+{
+    if (fileItem) {
+        QUrl url(fileItem->data(0, ReplaceMatches::FileUrlRole).toString());
+        int matches = fileItem->childCount();
+        return i18np("%1 match found in: %2\n", "%1 matches found in: %2\n", matches, url.toLocalFile());
+    }
+    return QString();
+}
+
+static QString copySearchMatch(QTreeWidgetItem *matchItem)
+{
+    if (matchItem) {
+        int startLine = matchItem->data(0, ReplaceMatches::StartLineRole).toInt();
+        int startColumn = matchItem->data(0, ReplaceMatches::StartColumnRole).toInt();
+        QString match = matchItem->data(0, ReplaceMatches::PreMatchRole).toString();
+        match += matchItem->data(0, ReplaceMatches::MatchRole).toString();
+        match += matchItem->data(0, ReplaceMatches::PostMatchRole).toString();
+        return i18n("\tLine: %1 column: %2: %3\n", startLine, startColumn, match);
+    }
+    return QString();
+}
+
+void KatePluginSearchView::copySearchToClipboard(CopyResultType copyType)
+{
+    Results *res = qobject_cast<Results *>(m_ui.resultTabWidget->currentWidget());
+    if (!res) {
+        return;
+    }
+    if (res->tree->topLevelItemCount() == 0) {
+        return;
+    }
+
+    QString clipboard;
+
+    QTreeWidgetItem *currentItem = res->tree->topLevelItem(0);
+
+    QTreeWidgetItem *parent = currentItem->parent();
+    if (currentItem->childCount() == 0) {
+        // this is probably a single match
+        if (parent) {
+            clipboard += copySearchMatchFile(parent);
+            clipboard += copySearchMatch(currentItem);
+        }
+        else {
+            clipboard = i18n("No matches found\n");
+        }
+    }
+    else {
+        if (parent) {
+            clipboard += copySearchSummary(parent);
+            clipboard += copySearchMatchFile(currentItem);
+        }
+        else {
+            clipboard += m_isSearchAsYouType ? copySearchMatchFile(currentItem) : copySearchSummary(currentItem);
+        }
+
+        for (int i=0; i<currentItem->childCount() && (currentItem->isExpanded() || copyType == All); ++i) {
+            QTreeWidgetItem *child = currentItem->child(i);
+            if (child->childCount() == 0) {
+                clipboard += copySearchMatch(child);
+            }
+            else {
+                clipboard += copySearchMatchFile(child);
+                for (int j=0; j<child->childCount() && (child->isExpanded() || copyType == All); ++j) {
+                    QTreeWidgetItem *grandChild = child->child(j);
+                    clipboard += copySearchMatch(grandChild);
+                }
+            }
+        }
+    }
+    QApplication::clipboard()->setText(clipboard);
+}
+
 bool KatePluginSearchView::eventFilter(QObject *obj, QEvent *event)
 {
-    if (event->type() == QEvent::KeyPress) {
+    if (event->type() == QEvent::ShortcutOverride) {
+        // Ignore copy in ShortcutOverride and handle it in the KeyPress event
+        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
+        if (ke->matches(QKeySequence::Copy)) {
+            event->accept();
+            return true;
+        }
+    }
+    else if (event->type() == QEvent::KeyPress) {
         QKeyEvent *ke = static_cast<QKeyEvent *>(event);
         QTreeWidget *tree = qobject_cast<QTreeWidget *>(obj);
         if (tree) {
             if (ke->matches(QKeySequence::Copy)) {
-                // user pressed ctrl+c -> copy full URL to the clipboard
-                QVariant variant = tree->currentItem()->data(0, ReplaceMatches::FileUrlRole);
-                QApplication::clipboard()->setText(variant.toString());
+                copySearchToClipboard(All);
                 event->accept();
                 return true;
             }
@@ -2157,7 +2294,7 @@ bool KatePluginSearchView::eventFilter(QObject *obj, QEvent *event)
         }
         // NOTE: Qt::Key_Escape is handled by handleEsc
     }
-    if (event->type() == QEvent::Resize) {
+    else if (event->type() == QEvent::Resize) {
         QResizeEvent *re = static_cast<QResizeEvent *>(event);
         if (obj == m_toolView) {
             onResize(re->size());
@@ -2272,65 +2409,6 @@ void KatePluginSearchView::slotProjectFileNameChanged()
     }
 }
 
-KateSearchCommand::KateSearchCommand(QObject *parent)
-    : KTextEditor::Command(QStringList() << QStringLiteral("grep") << QStringLiteral("newGrep") << QStringLiteral("search") << QStringLiteral("newSearch") << QStringLiteral("pgrep") << QStringLiteral("newPGrep"), parent)
-{
-}
-
-bool KateSearchCommand::exec(KTextEditor::View * /*view*/, const QString &cmd, QString & /*msg*/, const KTextEditor::Range &)
-{
-    // create a list of args
-    QStringList args(cmd.split(QLatin1Char(' '), QString::KeepEmptyParts));
-    QString command = args.takeFirst();
-    QString searchText = args.join(QLatin1Char(' '));
-
-    if (command == QLatin1String("grep") || command == QLatin1String("newGrep")) {
-        emit setSearchPlace(KatePluginSearchView::Folder);
-        emit setCurrentFolder();
-        if (command == QLatin1String("newGrep"))
-            emit newTab();
-    }
-
-    else if (command == QLatin1String("search") || command == QLatin1String("newSearch")) {
-        emit setSearchPlace(KatePluginSearchView::OpenFiles);
-        if (command == QLatin1String("newSearch"))
-            emit newTab();
-    }
-
-    else if (command == QLatin1String("pgrep") || command == QLatin1String("newPGrep")) {
-        emit setSearchPlace(KatePluginSearchView::Project);
-        if (command == QLatin1String("newPGrep"))
-            emit newTab();
-    }
-
-    emit setSearchString(searchText);
-    emit startSearch();
-
-    return true;
-}
-
-bool KateSearchCommand::help(KTextEditor::View * /*view*/, const QString &cmd, QString &msg)
-{
-    if (cmd.startsWith(QLatin1String("grep"))) {
-        msg = i18n("Usage: grep [pattern to search for in folder]");
-    } else if (cmd.startsWith(QLatin1String("newGrep"))) {
-        msg = i18n("Usage: newGrep [pattern to search for in folder]");
-    }
-
-    else if (cmd.startsWith(QLatin1String("search"))) {
-        msg = i18n("Usage: search [pattern to search for in open files]");
-    } else if (cmd.startsWith(QLatin1String("newSearch"))) {
-        msg = i18n("Usage: search [pattern to search for in open files]");
-    }
-
-    else if (cmd.startsWith(QLatin1String("pgrep"))) {
-        msg = i18n("Usage: pgrep [pattern to search for in current project]");
-    } else if (cmd.startsWith(QLatin1String("newPGrep"))) {
-        msg = i18n("Usage: newPGrep [pattern to search for in current project]");
-    }
-
-    return true;
-}
 
 #include "plugin_search.moc"
 
