@@ -1,6 +1,6 @@
 /*   Kate search plugin
  *
- * Copyright (C) 2011-2013 by Kåre Särs <kare.sars@iki.fi>
+ * Copyright (C) 2011-2020 by Kåre Särs <kare.sars@iki.fi>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #include "search_open_files.h"
 
 class KateSearchCommand;
+class QPoint;
 namespace KTextEditor
 {
 class MovingRange;
@@ -56,7 +57,7 @@ public:
     int matches = 0;
     QRegularExpression regExp;
     bool useRegExp = false;
-    bool matchCase;
+    bool matchCase = false;
     QString replaceStr;
     int searchPlaceIndex = 0;
     QString treeRootText;
@@ -108,6 +109,7 @@ public:
     void writeSessionConfig(KConfigGroup &config) override;
 
 public Q_SLOTS:
+    void stopClicked();
     void startSearch();
     void setSearchString(const QString &pattern);
     void navigateFolderUp();
@@ -116,6 +118,12 @@ public Q_SLOTS:
     void goToNextMatch();
     void goToPreviousMatch();
 
+private:
+    enum CopyResultType {
+        AllExpanded,
+        All
+    };
+
 private Q_SLOTS:
     void openSearchView();
     void handleEsc(QEvent *e);
@@ -169,6 +177,9 @@ private Q_SLOTS:
     void slotPluginViewDeleted(const QString &name, QObject *pluginView);
     void slotProjectFileNameChanged();
 
+    void copySearchToClipboard(CopyResultType type);
+    void customResMenuRequested(const QPoint &pos);
+
 protected:
     bool eventFilter(QObject *obj, QEvent *ev) override;
     void addHeaderItem();
@@ -179,22 +190,23 @@ private:
 
     void onResize(const QSize &size);
 
-    Ui::SearchDialog m_ui;
+    Ui::SearchDialog m_ui{};
     QWidget *m_toolView;
     KTextEditor::Application *m_kateApp;
     SearchOpenFiles m_searchOpenFiles;
     FolderFilesList m_folderFilesList;
     SearchDiskFiles m_searchDiskFiles;
     ReplaceMatches m_replacer;
-    QAction *m_matchCase;
-    QAction *m_useRegExp;
-    Results *m_curResults;
-    bool m_searchJustOpened;
-    int m_projectSearchPlaceIndex;
-    bool m_searchDiskFilesDone;
-    bool m_searchOpenFilesDone;
-    bool m_isSearchAsYouType;
-    bool m_isLeftRight;
+    QAction *m_matchCase = nullptr;
+    QAction *m_useRegExp = nullptr;
+    Results *m_curResults = nullptr;
+    bool m_searchJustOpened = false;
+    int m_projectSearchPlaceIndex = 0;
+    bool m_searchDiskFilesDone = true;
+    bool m_searchOpenFilesDone = true;
+    bool m_isSearchAsYouType = false;
+    bool m_isLeftRight = false;
+    bool m_blockDiskMatchFound = false;
     QString m_resultBaseDir;
     QList<KTextEditor::MovingRange *> m_matchRanges;
     QTimer m_changeTimer;
@@ -204,7 +216,7 @@ private:
     /**
      * current project plugin view, if any
      */
-    QObject *m_projectPluginView;
+    QObject *m_projectPluginView = nullptr;
 
     /**
      * our main window
@@ -212,27 +224,6 @@ private:
     KTextEditor::MainWindow *m_mainWindow;
 };
 
-class KateSearchCommand : public KTextEditor::Command
-{
-    Q_OBJECT
-public:
-    KateSearchCommand(QObject *parent);
-
-Q_SIGNALS:
-    void setSearchPlace(int place);
-    void setCurrentFolder();
-    void setSearchString(const QString &pattern);
-    void startSearch();
-    void newTab();
-
-    //
-    // KTextEditor::Command
-    //
-public:
-    bool exec(KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &range = KTextEditor::Range::invalid()) override;
-    bool help(KTextEditor::View *view, const QString &cmd, QString &msg) override;
-};
-
 #endif
 
 // kate: space-indent on; indent-width 4; replace-tabs on;
