@@ -42,6 +42,7 @@ void ReplaceMatches::replaceChecked(QTreeWidget *tree, const QRegularExpression
     m_regExp = regexp;
     m_replaceText = replace;
     m_cancelReplace = false;
+    m_terminateReplace = false;
     m_progressTime.restart();
     doReplaceNextMatch();
 }
@@ -56,6 +57,12 @@ void ReplaceMatches::cancelReplace()
     m_cancelReplace = true;
 }
 
+void ReplaceMatches::terminateReplace()
+{
+    m_cancelReplace = true;
+    m_terminateReplace = true;
+}
+
 KTextEditor::Document *ReplaceMatches::findNamed(const QString &name)
 {
     const QList<KTextEditor::Document *> docs = m_manager->documents();
@@ -201,6 +208,10 @@ bool ReplaceMatches::replaceSingleMatch(KTextEditor::Document *doc, QTreeWidgetI
 
 void ReplaceMatches::doReplaceNextMatch()
 {
+    if (m_terminateReplace) {
+        return;
+    }
+
     if (!m_manager || m_tree->topLevelItemCount() != 1) {
         updateTreeViewItems(nullptr);
         m_rootIndex = -1;
