@@ -1,10 +1,10 @@
- /***************************************************************************
-                          plugin_katetextfilter.h  -  description
-                             -------------------
-    begin                : FRE Feb 23 2001
-    copyright            : (C) 2001 by Joseph Wenninger
-    email                : jowenn@bigfoot.com
- ***************************************************************************/
+/***************************************************************************
+                         plugin_katetextfilter.h  -  description
+                            -------------------
+   begin                : FRE Feb 23 2001
+   copyright            : (C) 2001 by Joseph Wenninger
+   email                : jowenn@bigfoot.com
+***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -18,21 +18,21 @@
 #ifndef PLUGIN_KATETEXTFILTER_H
 #define PLUGIN_KATETEXTFILTER_H
 
-#include <KTextEditor/Plugin>
 #include <KTextEditor/Application>
-#include <KTextEditor/MainWindow>
-#include <KTextEditor/View>
-#include <KTextEditor/Document>
 #include <KTextEditor/Command>
+#include <KTextEditor/Document>
+#include <KTextEditor/MainWindow>
+#include <KTextEditor/Plugin>
+#include <KTextEditor/View>
 
 #include <KProcess>
 #include <QVariantList>
 
 class PluginKateTextFilter : public KTextEditor::Plugin
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     /**
      * Plugin constructor.
      */
@@ -42,18 +42,18 @@ class PluginKateTextFilter : public KTextEditor::Plugin
 
     QObject *createView(KTextEditor::MainWindow *mainWindow) override;
 
-    void runFilter(KTextEditor::View *kv, const QString & filter);
+    void runFilter(KTextEditor::View *kv, const QString &filter);
 
-  private:
-    QString  m_strFilterOutput;
-    QString  m_stderrOutput;
-    QString  m_last_command;
-    KProcess * m_pFilterProcess;
+private:
+    QString m_strFilterOutput;
+    QString m_stderrOutput;
+    QString m_last_command;
+    KProcess *m_pFilterProcess = nullptr;
     QStringList completionList;
-    bool copyResult;
-    bool mergeOutput;
-  public Q_SLOTS:
-    void slotEditFilter ();
+    bool copyResult = false;
+    bool mergeOutput = false;
+public Q_SLOTS:
+    void slotEditFilter();
     void slotFilterReceivedStdout();
     void slotFilterReceivedStderr();
     void slotFilterProcessExited(int exitCode, QProcess::ExitStatus exitStatus);
@@ -61,14 +61,13 @@ class PluginKateTextFilter : public KTextEditor::Plugin
 
 class PluginKateTextFilterCommand : public KTextEditor::Command
 {
-   Q_OBJECT
+    Q_OBJECT
 
 public:
-   PluginKateTextFilterCommand (PluginKateTextFilter *plugin);
+    PluginKateTextFilterCommand(PluginKateTextFilter *plugin);
     // Kate::Command
-    bool exec (KTextEditor::View *view, const QString &cmd, QString &msg,
-                      const KTextEditor::Range &range = KTextEditor::Range::invalid()) override;
-    bool help (KTextEditor::View *view, const QString &cmd, QString &msg) override;
+    bool exec(KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &range = KTextEditor::Range::invalid()) override;
+    bool help(KTextEditor::View *view, const QString &cmd, QString &msg) override;
 
 private:
     PluginKateTextFilter *m_plugin;
@@ -77,28 +76,28 @@ private:
 /**
  * Plugin view to merge the actions into the UI
  */
-class PluginViewKateTextFilter: public QObject, public KXMLGUIClient
+class PluginViewKateTextFilter : public QObject, public KXMLGUIClient
 {
     Q_OBJECT
 
-    public:
-        /**
-         * Construct plugin view
-         * @param plugin our plugin
-         * @param mainwindows the mainwindow for this view
-         */
-        explicit PluginViewKateTextFilter(PluginKateTextFilter *plugin, KTextEditor::MainWindow *mainwindow);
+public:
+    /**
+     * Construct plugin view
+     * @param plugin our plugin
+     * @param mainwindows the mainwindow for this view
+     */
+    explicit PluginViewKateTextFilter(PluginKateTextFilter *plugin, KTextEditor::MainWindow *mainwindow);
 
-        /**
-         * Our Destructor
-         */
-        ~PluginViewKateTextFilter() override;
+    /**
+     * Our Destructor
+     */
+    ~PluginViewKateTextFilter() override;
 
-    private:
-        /**
-         * the main window we belong to
-         */
-        KTextEditor::MainWindow *m_mainWindow;
+private:
+    /**
+     * the main window we belong to
+     */
+    KTextEditor::MainWindow *m_mainWindow;
 };
 
 #endif
