@@ -103,7 +103,6 @@ QObject *PluginKateXMLCheck::createView(KTextEditor::MainWindow *mainWindow)
 //---------------------------------
 PluginKateXMLCheckView::PluginKateXMLCheckView(KTextEditor::Plugin *plugin, KTextEditor::MainWindow *mainwin)
     : QObject(mainwin)
-    , KXMLGUIClient()
     , m_mainWindow(mainwin)
 {
     KXMLGUIClient::setComponentName(QStringLiteral("katexmlcheck"), i18n("Kate XML check")); // where i18n resources?
@@ -197,7 +196,11 @@ void PluginKateXMLCheckView::slotProcExited(int exitCode, QProcess::ExitStatus e
         list_count++;
     }
     if (!proc_stderr.isEmpty()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList lines = proc_stderr.split('\n', QString::SkipEmptyParts);
+#else
+        QStringList lines = proc_stderr.split('\n', Qt::SkipEmptyParts);
+#endif
         QString linenumber, msg;
         int line_count = 0;
         for (QStringList::Iterator it = lines.begin(); it != lines.end(); ++it) {
