@@ -1,43 +1,47 @@
-/* This file is part of the KDE project
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-   Copyright (C) 2009 Joseph Wenninger <jowenn@kde.org>
+    Copyright (C) 2009 Joseph Wenninger <jowenn@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _KATE_RUNNING_INSTANCE_INFO_
 #define _KATE_RUNNING_INSTANCE_INFO_
 
-#include <QMap>
-#include <QDBusInterface>
 #include <QDBusConnection>
+#include <QDBusInterface>
+#include <QMap>
 #include <QVariant>
 #include <iostream>
 
-class KateRunningInstanceInfo: public QObject
+class KateRunningInstanceInfo : public QObject
 {
     Q_OBJECT
 
 public:
-    KateRunningInstanceInfo(const QString &serviceName_):
-        QObject(), valid(false),
-        serviceName(serviceName_),
-        dbus_if(new QDBusInterface(serviceName_, QStringLiteral("/MainApplication"),
-                                   QString(), //I don't know why it does not work if I specify org.kde.Kate.Application here
-                                   QDBusConnection::sessionBus(), this)) {
+    KateRunningInstanceInfo(const QString &serviceName_)
+        : QObject()
+        , valid(false)
+        , serviceName(serviceName_)
+        , dbus_if(new QDBusInterface(serviceName_,
+                                     QStringLiteral("/MainApplication"),
+                                     QString(), // I don't know why it does not work if I specify org.kde.Kate.Application here
+                                     QDBusConnection::sessionBus(),
+                                     this))
+    {
         if (!dbus_if->isValid()) {
             std::cerr << qPrintable(QDBusConnection::sessionBus().lastError().message()) << std::endl;
         }
@@ -57,7 +61,8 @@ public:
             valid = true;
         }
     }
-    ~KateRunningInstanceInfo() override {
+    ~KateRunningInstanceInfo() override
+    {
         delete dbus_if;
     }
     bool valid;
@@ -75,4 +80,3 @@ Q_DECL_EXPORT bool fillinRunningKateAppInstances(KateRunningInstanceMap *map);
 Q_DECL_EXPORT void cleanupRunningKateAppInstanceMap(KateRunningInstanceMap *map);
 
 #endif
-
