@@ -63,9 +63,7 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent, cons
     // add tab bar
     m_tabBar = new KateTabBar(this);
     connect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
-    connect(m_tabBar, &KateTabBar::moreTabsRequested, this, &KateViewSpace::addTabs);
-    connect(m_tabBar, &KateTabBar::lessTabsRequested, this, &KateViewSpace::removeTabs);
-    connect(m_tabBar, &KateTabBar::closeTabRequested, this, &KateViewSpace::closeTabRequest, Qt::QueuedConnection);
+    connect(m_tabBar, &KateTabBar::tabCloseRequested, this, &KateViewSpace::closeTabRequest, Qt::QueuedConnection);
     connect(m_tabBar, &KateTabBar::contextMenuRequest, this, &KateViewSpace::showContextMenu, Qt::QueuedConnection);
     connect(m_tabBar, &KateTabBar::newTabRequested, this, &KateViewSpace::createNewDocument);
     connect(m_tabBar, SIGNAL(activateViewSpaceRequested()), this, SLOT(makeActive()));
@@ -118,11 +116,6 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent, cons
     // init the bars...
     statusBarToggled();
     tabBarToggled();
-
-    // make sure we show correct number of hidden documents
-    updateQuickOpen();
-    connect(KateApp::self()->documentManager(), &KateDocManager::documentCreated, this, &KateViewSpace::updateQuickOpen);
-    connect(KateApp::self()->documentManager(), &KateDocManager::documentsDeleted, this, &KateViewSpace::updateQuickOpen);
 }
 
 bool KateViewSpace::eventFilter(QObject *obj, QEvent *event)
@@ -229,6 +222,9 @@ KTextEditor::View *KateViewSpace::createView(KTextEditor::Document *doc)
         Q_ASSERT(m_lruDocList.contains(doc));
     }
 
+    // view shall still be not registered
+    Q_ASSERT(!m_docToView.contains(doc));
+
     // insert View into stack
     stack->addWidget(v);
     m_docToView[doc] = v;
@@ -276,36 +272,31 @@ bool KateViewSpace::showView(KTextEditor::Document *document)
     stack->setCurrentWidget(kv);
     kv->show();
 
+    /**
+     * we need to avoid that below's index changes will mess with current view
+     */
+    disconnect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
+
     // in case a tab does not exist, add one
-    if (!m_docToTabId.contains(document)) {
-        // if space is available, add button
-        if (m_tabBar->count() < m_tabBar->maxTabCount()) {
-            // just insert
-            insertTab(0, document);
-        } else {
-            // remove "oldest" button and replace with new one
-            Q_ASSERT(m_lruDocList.size() > m_tabBar->count());
-
-            // we need to subtract by 1 more, as we just added ourself to the end of the lru list!
-            KTextEditor::Document *docToHide = m_lruDocList[m_lruDocList.size() - m_tabBar->maxTabCount() - 1];
-            Q_ASSERT(m_docToTabId.contains(docToHide));
-            removeTab(docToHide, false);
-
-            // add new one always at the beginning
-            insertTab(0, document);
-        }
+    if (m_tabBar->documentIdx(document) == -1) {
+        insertTab(-1, document);
     }
 
     // follow current view
-    Q_ASSERT(m_docToTabId.contains(document));
-    m_tabBar->setCurrentTab(m_docToTabId.value(document, -1));
+    m_tabBar->setCurrentIndex(m_tabBar->documentIdx(document));
 
+    // track tab changes again
+    connect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
     return true;
 }
 
-void KateViewSpace::changeView(int id)
+void KateViewSpace::changeView(int idx)
 {
-    KTextEditor::Document *doc = m_docToTabId.key(id);
+    if (idx == -1) {
+        return;
+    }
+
+    KTextEditor::Document *doc = m_tabBar->tabDocument(idx);
     Q_ASSERT(doc);
 
     // make sure we open the view in this view space
@@ -347,15 +338,15 @@ void KateViewSpace::makeActive(bool focusCurrentView)
 
 void KateViewSpace::insertTab(int index, KTextEditor::Document *doc)
 {
+    if (m_tabBar->documentIdx(doc) != -1) {
+        return;
+    }
+
     // doc should be in the lru list
     Q_ASSERT(m_lruDocList.contains(doc));
 
-    // doc should not have a id
-    Q_ASSERT(!m_docToTabId.contains(doc));
+    m_tabBar->insertTab(index, doc);
 
-    const int id = m_tabBar->insertTab(index, doc->documentName());
-    m_tabBar->setTabToolTip(id, doc->url().toDisplayString());
-    m_docToTabId[doc] = id;
     updateDocumentState(doc);
 
     connect(doc, &KTextEditor::Document::documentNameChanged, this, &KateViewSpace::updateDocumentName);
@@ -371,11 +362,9 @@ int KateViewSpace::removeTab(KTextEditor::Document *doc, bool documentDestroyed)
     // Therefore, do not access any KTextEditor::Document functions here!
     // Only access QObject functions!
     //
-    Q_ASSERT(m_docToTabId.contains(doc));
 
-    const int id = m_docToTabId.value(doc, -1);
-    const int removeIndex = m_tabBar->removeTab(id);
-    m_docToTabId.remove(doc);
+    const int idx = m_tabBar->documentIdx(doc);
+    m_tabBar->removeTab(idx);
 
     if (!documentDestroyed) {
         disconnect(doc, &KTextEditor::Document::documentNameChanged, this, &KateViewSpace::updateDocumentName);
@@ -383,46 +372,7 @@ int KateViewSpace::removeTab(KTextEditor::Document *doc, bool documentDestroyed)
         disconnect(doc, &KTextEditor::Document::modifiedChanged, this, &KateViewSpace::updateDocumentState);
     }
 
-    return removeIndex;
-}
-
-void KateViewSpace::removeTabs(int count)
-{
-    const int start = count;
-
-    /// remove @p count tabs from the tab bar, as they do not all fit
-    while (count > 0) {
-        const int tabCount = m_tabBar->count();
-        KTextEditor::Document *removeDoc = m_lruDocList[m_lruDocList.size() - tabCount];
-        removeTab(removeDoc, false);
-        Q_ASSERT(!m_docToTabId.contains(removeDoc));
-        --count;
-    }
-
-    // make sure quick open shows the correct number of hidden documents
-    if (start != count) {
-        updateQuickOpen();
-    }
-}
-
-void KateViewSpace::addTabs(int count)
-{
-    const int start = count;
-
-    /// @p count tabs still fit into the tab bar: add as man as possible
-    while (count > 0) {
-        const int tabCount = m_tabBar->count();
-        if (m_lruDocList.size() <= tabCount) {
-            break;
-        }
-        insertTab(tabCount, m_lruDocList[m_lruDocList.size() - tabCount - 1]);
-        --count;
-    }
-
-    // make sure quick open shows the correct number of hidden documents
-    if (start != count) {
-        updateQuickOpen();
-    }
+    return idx;
 }
 
 void KateViewSpace::registerDocument(KTextEditor::Document *doc, bool append)
@@ -430,7 +380,6 @@ void KateViewSpace::registerDocument(KTextEditor::Document *doc, bool append)
     // at this point, the doc should be completely unknown
     Q_ASSERT(!m_lruDocList.contains(doc));
     Q_ASSERT(!m_docToView.contains(doc));
-    Q_ASSERT(!m_docToTabId.contains(doc));
 
     if (append) {
         m_lruDocList.append(doc);
@@ -438,23 +387,19 @@ void KateViewSpace::registerDocument(KTextEditor::Document *doc, bool append)
         // prepending == merge doc of closed viewspace
         m_lruDocList.prepend(doc);
     }
+
+    /**
+     * ensure we cleanup after document is deleted, e.g. we remove the tab bar button
+     */
     connect(doc, &QObject::destroyed, this, &KateViewSpace::documentDestroyed);
 
-    // if space is available, add button
-    if (m_tabBar->count() < m_tabBar->maxTabCount()) {
-        insertTab(0, doc);
-        updateQuickOpen();
-    } else if (append) {
-        // remove "oldest" button and replace with new one
-        Q_ASSERT(m_lruDocList.size() > m_tabBar->count());
-
-        KTextEditor::Document *docToHide = m_lruDocList[m_lruDocList.size() - m_tabBar->maxTabCount() - 1];
-        Q_ASSERT(m_docToTabId.contains(docToHide));
-        removeTab(docToHide, false);
-
-        // add new one at removed position
-        insertTab(0, doc);
-    }
+    /**
+     * register document is used in places that don't like view creation
+     * therefore we must ensure the currentChanged doesn't trigger that
+     */
+    disconnect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
+    insertTab(-1, doc);
+    connect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
 }
 
 void KateViewSpace::documentDestroyed(QObject *doc)
@@ -469,27 +414,18 @@ void KateViewSpace::documentDestroyed(QObject *doc)
     disconnect(doc, nullptr, this, nullptr);
 
     // case: there was no view created yet, but still a button was added
-    if (m_docToTabId.contains(invalidDoc)) {
+    if (m_tabBar->documentIdx(invalidDoc) != -1) {
         removeTab(invalidDoc, true);
-        // maybe show another tab button in its stead
-        if (m_lruDocList.size() >= m_tabBar->maxTabCount() && m_tabBar->count() < m_tabBar->maxTabCount()) {
-            KTextEditor::Document *docToShow = m_lruDocList[m_lruDocList.size() - m_tabBar->count() - 1];
-            Q_ASSERT(!m_docToTabId.contains(docToShow));
-
-            // add tab that now fits into the bar
-            insertTab(m_tabBar->count(), docToShow);
-        }
     }
 
     // at this point, the doc should be completely unknown
     Q_ASSERT(!m_lruDocList.contains(invalidDoc));
     Q_ASSERT(!m_docToView.contains(invalidDoc));
-    Q_ASSERT(!m_docToTabId.contains(invalidDoc));
 }
 
 void KateViewSpace::updateDocumentName(KTextEditor::Document *doc)
 {
-    const int buttonId = m_docToTabId[doc];
+    const int buttonId = m_tabBar->documentIdx(doc);
     Q_ASSERT(buttonId >= 0);
     m_tabBar->setTabText(buttonId, doc->documentName());
     m_tabBar->setTabToolTip(buttonId, doc->url().toDisplayString());
@@ -497,7 +433,7 @@ void KateViewSpace::updateDocumentName(KTextEditor::Document *doc)
 
 void KateViewSpace::updateDocumentUrl(KTextEditor::Document *doc)
 {
-    const int buttonId = m_docToTabId[doc];
+    const int buttonId = m_tabBar->documentIdx(doc);
     Q_ASSERT(buttonId >= 0);
     m_tabBar->setTabUrl(buttonId, doc->url());
 }
@@ -509,14 +445,13 @@ void KateViewSpace::updateDocumentState(KTextEditor::Document *doc)
         icon = QIcon::fromTheme(QStringLiteral("document-save"));
     }
 
-    Q_ASSERT(m_docToTabId.contains(doc));
-    const int buttonId = m_docToTabId[doc];
+    const int buttonId = m_tabBar->documentIdx(doc);
     m_tabBar->setTabIcon(buttonId, icon);
 }
 
-void KateViewSpace::closeTabRequest(int id)
+void KateViewSpace::closeTabRequest(int idx)
 {
-    KTextEditor::Document *doc = m_docToTabId.key(id);
+    auto *doc = m_tabBar->tabDocument(idx);
     Q_ASSERT(doc);
     m_viewManager->slotDocumentClose(doc);
 }
@@ -535,19 +470,6 @@ void KateViewSpace::createNewDocument()
     m_viewManager->activateView(doc);
 }
 
-void KateViewSpace::updateQuickOpen()
-{
-    const int hiddenDocs = hiddenDocuments();
-
-    if (hiddenDocs == 0) {
-        m_quickOpen->setToolButtonStyle(Qt::ToolButtonIconOnly);
-        m_quickOpen->defaultAction()->setText(QString());
-    } else {
-        m_quickOpen->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-        m_quickOpen->defaultAction()->setText(i18nc("indicator for more documents", "+%1", hiddenDocs));
-    }
-}
-
 void KateViewSpace::focusPrevTab()
 {
     const int id = m_tabBar->prevTab();
@@ -571,14 +493,14 @@ int KateViewSpace::hiddenDocuments() const
     return hiddenDocs;
 }
 
-void KateViewSpace::showContextMenu(int id, const QPoint &globalPos)
+void KateViewSpace::showContextMenu(int idx, const QPoint &globalPos)
 {
     // right now, show no context menu on empty tab bar space
-    if (id < 0) {
+    if (idx < 0) {
         return;
     }
 
-    KTextEditor::Document *doc = m_docToTabId.key(id);
+    auto *doc = m_tabBar->tabDocument(idx);
     Q_ASSERT(doc);
 
     auto addActionFromCollection = [this](QMenu *menu, const char *action_name) {
@@ -634,7 +556,7 @@ void KateViewSpace::showContextMenu(int id, const QPoint &globalPos)
     }
 
     if (choice == aCloseTab) {
-        closeTabRequest(id);
+        closeTabRequest(idx);
     } else if (choice == aCloseOthers) {
         KateApp::self()->documentManager()->closeOtherDocuments(doc);
     } else if (choice == aCopyPath) {
@@ -723,6 +645,7 @@ void KateViewSpace::restoreConfig(KateViewManager *viewMan, const KConfigBase *c
             auto view = viewMan->createView(doc, this);
             if (view) {
                 view->readSessionConfig(configGroup);
+                m_tabBar->setCurrentDocument(doc);
             }
         }
     }
