@@ -134,16 +134,6 @@ private Q_SLOTS:
      */
     int removeTab(KTextEditor::Document *doc, bool documentDestroyed);
 
-    /**
-     * Remove @p count tabs, since the tab bar shrunk.
-     */
-    void removeTabs(int count);
-
-    /**
-     * Add @p count tabs, since the tab bar grew.
-     */
-    void addTabs(int count);
-
     /**
      * This slot is called by the tabbar, if tab @p id was closed through the
      * context menu.
@@ -164,11 +154,6 @@ private Q_SLOTS:
      */
     void createNewDocument();
 
-    /**
-     * Update the quick open button to reflect the currently hidden tabs.
-     */
-    void updateQuickOpen();
-
 private:
     /**
      * Returns the amount of documents in KateDocManager that currently
@@ -207,9 +192,6 @@ private:
 
     // quick open action
     QToolButton *m_quickOpen;
-
-    // map from Document to button id
-    QHash<KTextEditor::Document *, int> m_docToTabId;
 };
 
 #endif
